/* -*- c-file-style: "ruby" -*- */
/************************************************

  global.h -

  $Author: mutoh $
  $Date: 2002/08/19 11:20:14 $

  Copyright (C) 1998-2000 Yukihiro Matsumoto,
                          Daisuke Kanda,
                          Hiroshi Igarashi
************************************************/

#ifndef _RBGTK_GLOBAL_H
#define _RBGTK_GLOBAL_H

#include "rbgtk.h"

extern void Init_gtk_gdk();
extern void Init_gtk_gtk();
extern void Init_gtk_accel_group();
extern void Init_gtk_accel_label();
extern void Init_gtk_adjustment();
extern void Init_gtk_alignment();
extern void Init_gtk_arg();
extern void Init_gtk_arrow();
extern void Init_gtk_aspect_frame();
extern void Init_gtk_bin();
extern void Init_gtk_box();
extern void Init_gtk_button();
extern void Init_gtk_button_box();
extern void Init_gtk_calendar();
extern void Init_gtk_check_button();
extern void Init_gtk_check_menu_item();
extern void Init_gtk_clist();
extern void Init_gtk_color_selection();
extern void Init_gtk_color_selection_dialog();
extern void Init_gtk_combo();
extern void Init_gtk_const();
extern void Init_gtk_container();
extern void Init_gtk_ctree();
extern void Init_gtk_curve();
extern void Init_gtk_data();
extern void Init_gtk_dialog();
extern void Init_gtk_drawing_area();
extern void Init_gtk_editable();
extern void Init_gtk_entry();
extern void Init_gtk_eventbox();
extern void Init_gtk_file_selection();
extern void Init_gtk_fixed();
extern void Init_gtk_font_selection();
extern void Init_gtk_font_selection_dialog();
extern void Init_gtk_frame();
extern void Init_gtk_gamma_curve();
extern void Init_gtk_gdkkeysyms();
extern void Init_gtk_handle_box();
extern void Init_gtk_hbox();
extern void Init_gtk_hbutton_box();
extern void Init_gtk_hpaned();
extern void Init_gtk_hruler();
extern void Init_gtk_hscale();
extern void Init_gtk_hscrollbar();
extern void Init_gtk_hseparator();
extern void Init_gtk_image();
extern void Init_gtk_input_dialog();
extern void Init_gtk_item();
extern void Init_gtk_label();
extern void Init_gtk_layout();
extern void Init_gtk_list();
extern void Init_gtk_list_item();
extern void Init_gtk_main();
extern void Init_gtk_menu();
extern void Init_gtk_menu_bar();
extern void Init_gtk_menu_item();
extern void Init_gtk_menu_shell();
extern void Init_gtk_misc();
extern void Init_gtk_notebook();
extern void Init_gtk_object();
extern void Init_gtk_option_menu();
extern void Init_gtk_paned();
extern void Init_gtk_pixmap();
extern void Init_gtk_plug();
extern void Init_gtk_preview();
extern void Init_gtk_progress();
extern void Init_gtk_progress_bar();
extern void Init_gtk_radio_button();
extern void Init_gtk_radio_menu_item();
extern void Init_gtk_range();
extern void Init_gtk_rc();
extern void Init_gtk_ruler();
extern void Init_gtk_scale();
extern void Init_gtk_scrollbar();
extern void Init_gtk_scrolled_window();
extern void Init_gtk_separator();
extern void Init_gtk_socket();
extern void Init_gtk_spin_button();
extern void Init_gtk_statusbar();
extern void Init_gtk_style();
extern void Init_gtk_table();
extern void Init_gtk_tearoff_menu_item();
extern void Init_gtk_text();
extern void Init_gtk_tips_query();
extern void Init_gtk_toggle_button();
extern void Init_gtk_toolbar();
extern void Init_gtk_tooltips();
extern void Init_gtk_tree();
extern void Init_gtk_tree_item();
extern void Init_gtk_vbox();
extern void Init_gtk_vbutton_box();
extern void Init_gtk_viewport();
extern void Init_gtk_vpaned();
extern void Init_gtk_vruler();
extern void Init_gtk_vscale();
extern void Init_gtk_vscrollbar();
extern void Init_gtk_vseparator();
extern void Init_gtk_widget();
extern void Init_gtk_window();
extern void Init_gtk_itemfactory();
extern void Init_gtk_selectiondata();
extern void Init_gtk_drag();

#endif /* _RBGTK_GLOBAL_H */
